#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = []

test_requirements = [
    "pytest>=3",
]

setup(
    author="Sarthak Vijayvergiya",
    author_email="sarthak@blueprintfinance.com",
    python_requires=">=3.9.13",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.9",
    ],
    description="Python Boilerplate contains all the boilerplate you need to create a Python package.",
    install_requires=requirements,
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="hbc_random_number",
    name="hbc_random_number",
    packages=find_packages(include=["hbc_random_number", "hbc_random_number.*"]),
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/sarthakvijayvergiya/hbc_random_number",
    version="0.2.0",
    zip_safe=False,
)
